@@ -516,8 +516,10 @@ Cpigemr2d(m, n,
 	  sendsize = block2buff(v_inter, vinter_nb, h_inter, hinter_nb,
 				ptrmyblock, ma, ptrsendbuff);
 	}	/* if (mesending...) { */
-	if (mesending && recver[step] >= 0 &&
-	    (sens == myrang > step)) {
+	//WCC if (mesending && recver[step] >= 0 &&
+	//WCC     (sens == myrang > step)) {
+	if (mesending && (recver[step] >= 0) &&
+	    (sens == (myrang > step))) {
 	  i = recver[step] / q1;
 	  j = recver[step] % q1;
 	  if (sendsize > 0
@@ -527,8 +529,10 @@ Cpigemr2d(m, n,
 		     0, proc1[i * q1 + j]);
 	  }	/* sendsize > 0 */
 	}	/* if (mesending ... */
-	if (merecving && sender[step] >= 0 &&
-	    (sens == myrang <= step)) {
+	//WCC if (merecving && sender[step] >= 0 &&
+	//WCC     (sens == myrang <= step)) {
+	if (merecving && (sender[step] >= 0) &&
+	    (sens == (myrang <= step))) {
 	  i = sender[step] / q0;
 	  j = sender[step] % q0;
 	  vinter_nb = scan_intervals('r', ib, ia, m, mb, ma, p1, p0, myprow1, i,
